@@ -12,15 +12,16 @@ namespace sfc {
     R_xlen_t i;
     Rcpp::List sfcs(n);
 
+    SEXP geometry_cols = R_NilValue;
+    SEXP linestring_id = R_NilValue;
+
     for( i = 0; i < n; ++i ) {
       SEXP x = lst[i];
-      sfcs[i] = sfheaders::sfc::sfc_linestring( x, xyzm );
+      sfcs[i] = sfheaders::sfc::sfc_linestring( x, geometry_cols, linestring_id, xyzm );
     }
     return sfcs;
   }
 
-
-
 } // sfc
 } // sfheaders
 
